@@ -6,7 +6,7 @@ Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
 
 =head1 VERSION
 
-0.19
+0.20
 
 =head1 DESCRIPTION
 
@@ -103,6 +103,8 @@ Caching is EXPERIMENTAL and could be removed without notice.
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video>
 
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn>
+
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv>
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip>
@@ -142,7 +144,7 @@ use Mojo::UserAgent;
 use Mojolicious::Plugin::LinkEmbedder::Link;
 use constant DEBUG => $ENV{MOJO_LINKEMBEDDER_DEBUG} || 0;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 has _ua => sub { Mojo::UserAgent->new(max_redirects => 3) };
 
@@ -248,6 +250,7 @@ sub register {
   my ($self, $app, $config) = @_;
 
   $self->{classes} = {
+    'appear'       => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn',
     '2play'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play',
     'beta.dbtv'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
     'dbtv'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
